# CatalogGroupType

The type of the catalog group. 

## Enum

* `GRADING` (value: `'Grading'`)

* `DISPLAY` (value: `'Display'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


